@@ -1,18 +1,10 @@
 """Jupancon, connector to several DBs that returns pandas. Magic included."""
 
-__version__ = "0.1.1"
+__version__ = "0.1.2"
 
 
-from .core import (
-    query_raw,
-    list_schemas,
-    list_tables,
-    query,
-    df_to_table,
-    peek,
-    peek_schema,
-    change,
-)
+from .core import (change, df_to_table, list_schemas, list_tables, peek,
+                   peek_schema, query, query_raw)
 
 
 # snippet to check if the environment is interactive
@@ -24,13 +16,11 @@ def is_interactive():
 
 def load_magics():
     if is_interactive():
-        from .magic import load_ipython_extension
         from IPython import get_ipython
 
+        from .magic import load_ipython_extension
+
         load_ipython_extension(get_ipython())
         print("SQL magics loaded!")
     else:
         print("Non interactive environment detected, no magics loaded")
-
-
-__version__ = "0.3.0"
